@@ -25,6 +25,7 @@ typedef struct _TangleLayoutClass TangleLayoutClass;
 
 #include "tangle-widget.h"
 #include "tangle-layout-meta.h"
+#include "tangle-trick.h"
 
 struct _TangleLayout {
 	GObject parent_instance;
@@ -75,6 +76,17 @@ void tangle_layout_allocate_actor(TangleLayout* layout, ClutterActor* actor, Clu
 TangleLayoutDirection tangle_layout_get_direction(TangleLayout* layout);
 void tangle_layout_set_direction(TangleLayout* layout, TangleLayoutDirection direction);
 
+gboolean tangle_layout_get_use_fixed_position(TangleLayout* layout);
+void tangle_layout_set_use_fixed_position(TangleLayout* layout, gboolean use_fixed_position);
+
+GList* tangle_layout_get_tricks(TangleLayout* layout);
+TangleTrick* tangle_layout_get_trick_by_type(TangleLayout* layout, GType type);
+void tangle_layout_add_trick(TangleLayout* layout, TangleTrick* trick);
+void tangle_layout_remove_trick(TangleLayout* layout, TangleTrick* trick);
+void tangle_layout_clear_tricks(TangleLayout* layout);
+
 TangleLayoutMeta* tangle_layout_get_meta(TangleLayout* layout, ClutterActor* actor);
 
+void tangle_layout_changed(TangleLayout* layout);
+
 #endif
