@@ -25,8 +25,10 @@ typedef struct _TangleValueCalculationFunctions {
 gboolean tangle_init(int* argc, char*** argv);
 
 #define TANGLE_UNREF_AND_NULLIFY_OBJECT(x) ((x) = tangle_unref_object(x))
+#define TANGLE_UNPARENT_AND_NULLIFY_ACTOR(x) ((x) = tangle_unparent_actor(x))
 
 gpointer tangle_unref_object(gpointer object);
+ClutterActor* tangle_unparent_actor(ClutterActor* actor);
 
 typedef gpointer TanglePointers;
 
@@ -59,4 +61,11 @@ void tangle_value_register_calculation_functions(GType value_type, TangleValueCa
 gchar* tangle_lookup_filename(const gchar* filename);
 void tangle_add_search_path(const gchar* search_path);
 
+ClutterAnimation* tangle_object_animate(GObject* object, gulong mode, guint duration, ...);
+ClutterAnimation* tangle_object_animate_with_timeline(GObject* object, gulong mode, ClutterTimeline* timeline, ...);
+ClutterAnimation* tangle_object_animatev(GObject* object, gulong mode, guint duration, gint n_properties, const gchar* const property_names[], const GValue* property_values);
+ClutterAnimation* tangle_object_animate_valist(GObject* object, gulong mode, guint duration, va_list properties);
+ClutterAnimation* tangle_object_animate_valist_with_timeline(GObject* object, gulong mode, ClutterTimeline* timeline, va_list properties);
+gboolean tangle_object_stop_animation(GObject* object, ClutterAnimation* animation);
+
 #endif
