@@ -69,7 +69,7 @@ void tangle_scroll_trick_set_axis(TangleScrollTrick* scroll_trick, TangleScrollA
 	if (scroll_trick->priv->axis != axis) {
 		scroll_trick->priv->axis = axis;
 		g_object_notify(G_OBJECT(scroll_trick), "axis");
-		tangle_layout_changed(tangle_trick_get_layout(TANGLE_TRICK(scroll_trick)));
+		tangle_trick_layout_changed(TANGLE_TRICK(scroll_trick));
 	}
 }
 
