@@ -434,31 +434,6 @@ static void tangle_scroller_paint_children(TangleWidget* widget) {
 	}
 }
 
-static void tangle_scroller_handle_descendant_event(TangleActor* actor, TangleEvent* event) {
-	TangleScroller* scroller;
-	
-	scroller = TANGLE_SCROLLER(actor);
-	
-	if (event->any.sender != actor) {
-		switch (event->type) {
-			case TANGLE_EVENT_INTERACTION_BEGAN:
-				scroller->priv->descendant_interacting = TRUE;
-				if (event->interaction.dragging) {
-					scroller->priv->descendant_dragging = TRUE;
-				}
-				break;
-			case TANGLE_EVENT_INTERACTION_ENDED:
-				scroller->priv->descendant_interacting = FALSE;
-				scroller->priv->descendant_dragging = FALSE;
-				break;
-			default:
-				break;
-		}
-	}
-
-	TANGLE_ACTOR_CLASS(tangle_scroller_parent_class)->handle_descendant_event(actor, event);
-}
-
 static void tangle_scroller_clamp_scrolling_offset_x_impl(TangleScroller* scroller, TangleClamp* clamp) {
 	if (!tangle_clamp_get_clamped_value_set(clamp) && !scroller->priv->continuous_x) {
 		if (scroller->priv->scrolling_offset_x < 0.0) {
@@ -606,8 +581,6 @@ static void tangle_scroller_class_init(TangleScrollerClass* scroller_class) {
 	
 	clutter_actor_class->button_press_event = tangle_scroller_button_press_event;
 	
-	actor_class->handle_descendant_event = tangle_scroller_handle_descendant_event;
-
 	widget_class->allocate_children = tangle_scroller_allocate_children;
 	widget_class->paint_children = tangle_scroller_paint_children;
 	
@@ -1020,15 +993,6 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 }
 
 static void send_interaction_event(TangleActor* actor, gboolean began) {
-	TangleEvent* event;
-	
-	event = tangle_event_new((began ? TANGLE_EVENT_INTERACTION_BEGAN : TANGLE_EVENT_INTERACTION_ENDED),
-	                         TANGLE_ACTOR(actor));
-	event->interaction.x_axis = TRUE;
-	event->interaction.y_axis = TRUE;
-	event->interaction.dragging = TRUE;
-	tangle_actor_send_event(actor, event);
-	tangle_event_free(event);
 }
 
 static gfloat get_width(TangleScroller* scroller) {
