@@ -491,35 +491,6 @@ static void tangle_scrolling_actor_paint_wrapped(TangleWrapperActor* wrapper_act
 	}
 }
 
-static void tangle_scrolling_actor_handle_descendant_event(TangleActor* actor, TangleEvent* event) {
-	TangleScrollingActor* scrolling_actor;
-	
-	scrolling_actor = TANGLE_SCROLLING_ACTOR(actor);
-
-	if (event->any.sender != actor) {
-		switch (event->type) {
-			case TANGLE_EVENT_INTERACTION_BEGAN:
-				scrolling_actor->priv->descendant_interacting = TRUE;
-				if (event->interaction.dragging) {
-					scrolling_actor->priv->descendant_dragging = TRUE;
-				}
-				if (scrolling_actor->priv->scrolling_effective && scrolling_actor->priv->descendant_dragging) {
-					tangle_scrolling_actor_clamp_offsets(scrolling_actor);
-					stop_interacting(scrolling_actor);
-				}
-				break;
-			case TANGLE_EVENT_INTERACTION_ENDED:
-				scrolling_actor->priv->descendant_interacting = FALSE;
-				scrolling_actor->priv->descendant_dragging = FALSE;
-				break;
-			default:
-				break;
-		}
-	}
-
-	TANGLE_ACTOR_CLASS(tangle_scrolling_actor_parent_class)->handle_descendant_event(actor, event);
-}
-
 static void tangle_scrolling_actor_clamp_scrolling_offset_x_impl(TangleScrollingActor* scrolling_actor, TangleClamp* clamp) {
 	if (!tangle_clamp_get_clamped_value_set(clamp) && !scrolling_actor->priv->continuous[HORIZONTAL]) {
 		if (scrolling_actor->priv->scrolling_offset[HORIZONTAL] < 0.0) {
@@ -683,8 +654,6 @@ static void tangle_scrolling_actor_class_init(TangleScrollingActorClass* scrolli
 	clutter_actor_class->button_press_event = tangle_scrolling_actor_button_press_event;
 	clutter_actor_class->map = tangle_scrolling_actor_map;
 	
-	actor_class->handle_descendant_event = tangle_scrolling_actor_handle_descendant_event;
-
 	wrapper_actor_class->allocate_wrapped = tangle_scrolling_actor_allocate_wrapped;
 	wrapper_actor_class->paint_wrapped = tangle_scrolling_actor_paint_wrapped;
 	
@@ -906,7 +875,7 @@ static void handle_event(TangleScrollingActor* scrolling_actor, Axis axis, gfloa
 	gdouble v, a;
 	guint t;
 	TangleClamp* clamp;
-	gfloat delta;
+	gfloat delta = 0.0;
 
 	backend = clutter_get_default_backend();
 	d = coordinate - scrolling_actor->priv->start_scrolling_motion[axis];
@@ -918,8 +887,6 @@ static void handle_event(TangleScrollingActor* scrolling_actor, Axis axis, gfloa
 		if (!scrolling_actor->priv->scrolling_effective[axis] ||
 		    event_time - scrolling_actor->priv->previous_motion_time > clutter_backend_get_double_click_time(backend)) {
 			if (!scrolling_actor->priv->scrolling_effective[axis]) {		
-				tangle_actor_send_interaction_began_event(TANGLE_ACTOR(scrolling_actor), TRUE, TRUE, TRUE);
-
 				scrolling_actor->priv->scrolling_effective[axis] = TRUE;
 				scrolling_actor->priv->start_scrolling_motion[axis] = coordinate;
 				scrolling_actor->priv->start_scrolling_offset[axis] = scrolling_actor->priv->scrolling_offset[axis];
@@ -1102,7 +1069,6 @@ static void stop_interacting(TangleScrollingActor* scrolling_actor) {
 	if (scrolling_actor->priv->captured_event_handler_id) {
 		g_signal_handler_disconnect(clutter_actor_get_stage(CLUTTER_ACTOR(scrolling_actor)), scrolling_actor->priv->captured_event_handler_id);
 		scrolling_actor->priv->captured_event_handler_id = 0;
-		tangle_actor_send_interaction_ended_event(TANGLE_ACTOR(scrolling_actor), TRUE, TRUE, TRUE);
 	}
 }
 
