@@ -22,7 +22,7 @@ int main(int argc, char** argv) {
 		g_critical("Could not find an object named 'main' from '%s'.", filename);
 	} else {
 		g_print("boolean: %s\n", (tangle_properties_get_boolean(properties, "boolean") ? "TRUE" : "FALSE"));
-		g_print("int: %ld\n", tangle_properties_get_int(properties, "int"));
+		g_print("int: %" G_GINT64_FORMAT "\n", tangle_properties_get_int(properties, "int"));
 		g_print("double: %lf\n", tangle_properties_get_double(properties, "double"));
 		g_print("string: %s\n", tangle_properties_get_string(properties, "string"));
 	}
